@@ -26,22 +26,33 @@
 #define INCLUDED_ANONGAME_MAPLISTS_PROTOS
 
 #define JUST_NEED_TYPES
-#include "common/packet.h"
+# include "common/packet.h"
+# include "common/tag.h"
 #undef JUST_NEED_TYPES
 
-extern int	anongame_maplists_create(void);
-extern void	anongame_maplists_destroy(void);
+namespace pvpgn
+{
 
-extern int	maplists_get_totalmaps(t_clienttag clienttag);
-extern int	maplists_get_totalmaps_by_queue(t_clienttag clienttag, int queue);
+	namespace bnetd
+	{
 
-extern void	maplists_add_maps_to_packet(t_packet * packet, t_clienttag clienttag);
-extern void	maplists_add_map_info_to_packet(t_packet * rpacket, t_clienttag clienttag, int queue);
+		extern int	anongame_maplists_create(void);
+		extern void	anongame_maplists_destroy(void);
 
-extern char *	maplists_get_map(int queue, t_clienttag clienttag, int mapnumber);
+		extern int	maplists_get_totalmaps(t_clienttag clienttag);
+		extern int	maplists_get_totalmaps_by_queue(t_clienttag clienttag, int queue);
 
-extern int	anongame_add_tournament_map(t_clienttag clienttag, char * mapname);
-extern void	anongame_tournament_maplists_destroy(void);
+		extern void	maplists_add_maps_to_packet(t_packet * packet, t_clienttag clienttag);
+		extern void	maplists_add_map_info_to_packet(t_packet * rpacket, t_clienttag clienttag, int queue);
+
+		extern char *	maplists_get_map(int queue, t_clienttag clienttag, int mapnumber);
+
+		extern int	anongame_add_tournament_map(t_clienttag clienttag, char * mapname);
+		extern void	anongame_tournament_maplists_destroy(void);
+
+	}
+
+}
 
 #endif
 #endif
