@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005  Dizzy 
+ * Copyright (C) 2005  Dizzy
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,14 +19,28 @@
 #ifndef __CMDLINE_H_PROTOS__
 #define __CMDLINE_H_PROTOS__
 
-extern int cmdline_load(int argc, char * * argv);
-extern void cmdline_unload(void);
+namespace pvpgn
+{
 
-/* options exported by cmdline */
+	namespace bnetd
+	{
+
+		extern int cmdline_load(int argc, char * * argv);
+		extern void cmdline_unload(void);
+
+		/* options exported by cmdline */
 #ifdef DO_DAEMONIZE
-extern int cmdline_get_foreground(void);
+		extern int cmdline_get_foreground(void);
 #endif
-extern const char* cmdline_get_preffile(void);
-extern const char* cmdline_get_hexfile(void);
+		extern const char* cmdline_get_preffile(void);
+		extern const char* cmdline_get_hexfile(void);
+#ifdef WIN32_GUI
+		extern unsigned cmdline_get_console(void);
+		extern unsigned cmdline_get_gui(void);
+#endif
+
+	}
+
+}
 
 #endif /* __CMDLINE_H_PROTOS__ */
