@@ -4,7 +4,17 @@
 
 #include "storage_file.h"
 
-extern t_file_engine file_plain;
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern t_file_engine file_plain;
+
+	}
+
+}
 
 #endif /* INClUDED_FILE_PLAIN_PROTOS */
 #endif /* JUST_NEED_TYPES */
