@@ -18,9 +18,22 @@
 #ifndef INCLUDED_HANDLE_D2CS_H
 #define INCLUDED_HANDLE_D2CS_H
 
-extern int handle_d2cs_packet(t_connection * c, t_packet const * packet);
-extern int handle_d2cs_init(t_connection * c);
-extern int send_d2cs_gameinforeq(t_connection * c);
+#include "common/packet.h"
+#include "connection.h"
+
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern int handle_d2cs_packet(t_connection * c, t_packet const * packet);
+		extern int handle_d2cs_init(t_connection * c);
+		extern int send_d2cs_gameinforeq(t_connection * c);
+
+	}
+
+}
 
 #endif
 
