@@ -27,7 +27,17 @@
 #include "common/packet.h"
 #undef JUST_NEED_TYPES
 
-extern int handle_telnet_packet(t_connection * c, t_packet const * const packet);
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern int handle_telnet_packet(t_connection * c, t_packet const * const packet);
+
+	}
+
+}
 
 #endif
 #endif
