@@ -19,14 +19,24 @@
 #ifndef INCLUDED_LADDER_CALC_TYPES
 #define INCLUDED_LADDER_CALC_TYPES
 
-typedef struct
+namespace pvpgn
 {
-    double       prob;
-    unsigned int k;
-    int          adj;
-    unsigned int oldrating;
-    unsigned int oldrank;
-} t_ladder_info;
+
+	namespace bnetd
+	{
+
+		typedef struct
+		{
+			double       prob;
+			unsigned int k;
+			int          adj;
+			unsigned int oldrating;
+			unsigned int oldrank;
+		} t_ladder_info;
+
+	}
+
+}
 
 #endif
 
@@ -42,7 +52,17 @@ typedef struct
 #include "common/tag.h"
 #undef JUST_NEED_TYPES
 
-extern int ladder_calc_info(t_clienttag clienttag, t_ladder_id id, unsigned int count, t_account * * players, t_game_result * results, t_ladder_info * info);
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern int ladder_calc_info(t_clienttag clienttag, t_ladder_id id, unsigned int count, t_account * * players, t_game_result * results, t_ladder_info * info);
+
+	}
+
+}
 
 #endif
 #endif
