@@ -22,12 +22,20 @@
 #ifndef INCLUDED_RUNPROG_PROTOS
 #define INCLUDED_RUNPROG_PROTOS
 
-#define JUST_NEED_TYPES
-#include <stdio.h>
-#undef JUST_NEED_TYPES
+#include <cstdio>
 
-extern FILE * runprog_open(char const * command);
-extern int runprog_close(FILE * pp);
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern std::FILE * runprog_open(char const * command);
+		extern int runprog_close(std::FILE * pp);
+
+	}
+
+}
 
 #endif
 #endif
