@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002,2003,2004 Dizzy 
+ * Copyright (C) 2002,2003,2004 Dizzy
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,13 +21,23 @@
 
 #include "storage.h"
 
-typedef const char t_file_info;
+namespace pvpgn
+{
 
-typedef struct {
-    t_attr * (*read_attr)(const char *filename, const char *key);
-    int (*read_attrs)(const char *filename, t_read_attr_func cb, void *data);
-    int (*write_attrs)(const char *filename, const t_hlist *attributes);
-} t_file_engine;
+	namespace bnetd
+	{
+
+		typedef const char t_file_info;
+
+		typedef struct {
+			t_attr * (*read_attr)(const char *filename, const char *key);
+			int(*read_attrs)(const char *filename, t_read_attr_func cb, void *data);
+			int(*write_attrs)(const char *filename, const t_hlist *attributes);
+		} t_file_engine;
+
+	}
+
+}
 
 #endif /* INClUDED_STORAGE_FILE_TYPES */
 
@@ -35,7 +45,17 @@ typedef struct {
 #ifndef INClUDED_STORAGE_FILE_PROTOS
 #define INClUDED_STORAGE_FILE_PROTOS
 
-extern t_storage storage_file;
+namespace pvpgn
+{
+
+	namespace bnetd
+	{
+
+		extern t_storage storage_file;
+
+	}
+
+}
 
 #endif /* INClUDED_STORAGE_FILE_PROTOS */
 #endif /* JUST_NEED_TYPES */
