@@ -20,6 +20,11 @@
 
 #define D2CHARSAVE_CHECKSUM_OFFSET			0x0C
 
-extern int d2charsave_checksum(unsigned char const * data, unsigned int len, unsigned int offset);
+namespace pvpgn
+{
+
+	extern int d2charsave_checksum(unsigned char const * data, unsigned int len, unsigned int offset);
+
+}
 
 #endif
