@@ -19,16 +19,24 @@
 #ifndef INCLUDED_EVENTLOG_TYPES
 #define INCLUDED_EVENTLOG_TYPES
 
-typedef enum
+namespace pvpgn
 {
-    eventlog_level_none = 0,
-    eventlog_level_trace= 1,
-    eventlog_level_debug= 2,
-    eventlog_level_info = 4,
-    eventlog_level_warn = 8,
-    eventlog_level_error=16,
-    eventlog_level_fatal=32
-} t_eventlog_level;
+
+	typedef enum
+	{
+		eventlog_level_none = 0,
+		eventlog_level_trace = 1,
+		eventlog_level_debug = 2,
+		eventlog_level_info = 4,
+		eventlog_level_warn = 8,
+		eventlog_level_error = 16,
+		eventlog_level_fatal = 32
+#ifdef WIN32_GUI
+		, eventlog_level_gui = 64
+#endif
+	} t_eventlog_level;
+
+}
 
 #endif
 
@@ -38,27 +46,29 @@ typedef enum
 #ifndef INCLUDED_EVENTLOG_PROTOS
 #define INCLUDED_EVENTLOG_PROTOS
 
-#define JUST_NEED_TYPES
-#include <stdio.h>
-#undef JUST_NEED_TYPES
+#include <cstdio>
+#include <common/format.h>
 
-extern void eventlog_set_debugmode(int debugmode);
-extern void eventlog_set(FILE * fp);
-extern FILE * eventlog_get(void);
-extern int eventlog_open(char const * filename);
-extern int eventlog_close(void);
-extern void eventlog_clear_level(void);
-extern int eventlog_add_level(char const * levelname);
-extern int eventlog_del_level(char const * levelname);
-extern char const * eventlog_get_levelname_str(t_eventlog_level level);
-extern void eventlog_hexdump_data(void const * data, unsigned int len);
-extern void eventlog(t_eventlog_level level, char const * module, char const * fmt, ...);
-extern void eventlog_step(char const * filename, t_eventlog_level level, char const * module, char const * fmt, ...);
+namespace pvpgn
+{
 
-#define FATAL0(fmt) eventlog(eventlog_level_fatal,__FUNCTION__,fmt)
-#define FATAL1(fmt,arg1) eventlog(eventlog_level_fatal,__FUNCTION__,fmt,arg1)
-#define FATAL2(fmt,arg1,arg2) eventlog(eventlog_level_fatal,__FUNCTION__,fmt,arg1,arg2)
-#define FATAL3(fmt,arg1,arg2,arg3) eventlog(eventlog_level_fatal,__FUNCTION__,fmt,arg1,arg2,arg3)
+	extern void eventlog_set_debugmode(int debugmode);
+	extern void eventlog_set(std::FILE * fp);
+	extern std::FILE * eventlog_get(void);
+	extern int eventlog_open(char const * filename);
+	extern int eventlog_close(void);
+	extern void eventlog_clear_level(void);
+	extern int eventlog_add_level(char const * levelname);
+	extern int eventlog_del_level(char const * levelname);
+	extern char const * eventlog_get_levelname_str(t_eventlog_level level);
+	extern void eventlog_hexdump_data(void const * data, unsigned int len);
+
+	void eventlog(t_eventlog_level level, const char* module, const char* format, fmt::ArgList args);
+	FMT_VARIADIC(void, eventlog, t_eventlog_level, const char*, const char*)
+	//template <typename... Args>
+	// extern void eventlog2(t_eventlog_level level, const char* module, const char* format, const Args& ... args);
+
+	extern void eventlog_step(char const * filename, t_eventlog_level level, char const * module, char const * fmt, ...) PRINTF_ATTR(4, 5);
 
 #define ERROR0(fmt) eventlog(eventlog_level_error,__FUNCTION__,fmt)
 #define ERROR1(fmt,arg1) eventlog(eventlog_level_error,__FUNCTION__,fmt,arg1)
@@ -85,6 +95,7 @@ extern void eventlog_step(char const * filename, t_eventlog_level level, char co
 #define TRACE2(fmt,arg1,arg2) eventlog(eventlog_level_trace,__FUNCTION__,fmt,arg1,arg2)
 #define TRACE3(fmt,arg1,arg2,arg3) eventlog(eventlog_level_trace,__FUNCTION__,fmt,arg1,arg2,arg3)
 
+}
 
 #endif
 #endif
