@@ -23,12 +23,15 @@
 #ifndef INCLUDED_HEXDUMP_PROTOS
 #define INCLUDED_HEXDUMP_PROTOS
 
-#define JUST_NEED_TYPES
-#include <stdio.h>
-#undef JUST_NEED_TYPES
+#include <cstdio>
 
-extern void hexdump(FILE * stream, void const * data, unsigned int len);
-extern void hexdump_string(unsigned char * data, unsigned int datalen, char * dst, unsigned int counter);
+namespace pvpgn
+{
+
+	extern void hexdump(std::FILE * stream, void const * data, unsigned int len);
+	extern void hexdump_string(unsigned char * data, unsigned int datalen, char * dst, unsigned int counter);
+
+}
 
 #endif
 #endif
