@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004  Dizzy 
+ * Copyright (C) 2004  Dizzy
  *
  * lstr is a structure to be used for cached string lengths for speed
  *
@@ -21,34 +21,44 @@
 #ifndef INCLUDED_LSTR_TYPES
 #define INCLUDED_LSTR_TYPES
 
-typedef struct lstr {
-    char *str;
-    unsigned len;
-} t_lstr;
+namespace pvpgn
+{
+
+	typedef struct lstr {
+		char *str;
+		unsigned len;
+	} t_lstr;
+
+}
 
 #endif /* INCLUDED_LSTR_TYPES */
 
 #ifndef INCLUDED_LSTR_PROTOS
 #define INCLUDED_LSTR_PROTOS
 
-static inline void lstr_set_str(t_lstr *lstr, char *str)
+namespace pvpgn
 {
-    lstr->str = str;
-}
 
-static inline char *lstr_get_str(t_lstr *lstr)
-{
-    return lstr->str;
-}
+	static inline void lstr_set_str(t_lstr *lstr, char *str)
+	{
+		lstr->str = str;
+	}
 
-static inline void lstr_set_len(t_lstr *lstr, unsigned len)
-{
-    lstr->len = len;
-}
+	static inline char *lstr_get_str(t_lstr *lstr)
+	{
+		return lstr->str;
+	}
+
+	static inline void lstr_set_len(t_lstr *lstr, unsigned len)
+	{
+		lstr->len = len;
+	}
+
+	static inline unsigned lstr_get_len(t_lstr *lstr)
+	{
+		return lstr->len;
+	}
 
-static inline unsigned lstr_get_len(t_lstr *lstr)
-{
-    return lstr->len;
 }
 
 #endif /* INCLUDED_LSTR_PROTOS */
