@@ -27,4 +27,8 @@
 # define F_OK	0	/* Test for existence.		*/
 #endif
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
 #endif
