@@ -18,19 +18,32 @@
 #ifndef INCLUDED_GETTIMEOFDAY_TYPES
 #define INCLUDED_GETTIMEOFDAY_TYPES
 
-#ifndef HAVE_GETTIMEOFDAY
-
-struct timezone
-{
-    int tz_minuteswest;
-    int tz_dsttime;
-};
-
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
 #endif
 
-/* we always require select thus we always require timeval which should
- * be available through portable socket layer */
-#include "psock.h"
+#ifndef HAVE_GETTIMEOFDAY
+
+namespace pvpgn
+{
+
+	/* FIXME: these might already exist even if gettimeofday() doesn't */
+	struct timeval
+	{
+		long tv_sec;
+		long tv_usec;
+	};
+
+
+	struct timezone
+	{
+		int tz_minuteswest;
+		int tz_dsttime;
+	};
+
+}
+
+#endif
 
 #endif
 
@@ -39,7 +52,12 @@ struct timezone
 #define INCLUDED_GETTIMEOFDAY_PROTOS
 
 #ifndef HAVE_GETTIMEOFDAY
-extern int gettimeofday(struct timeval * tv, struct timezone * tz);
+namespace pvpgn
+{
+
+	extern int gettimeofday(struct timeval * tv, struct timezone * tz);
+
+}
 #endif
 
 #endif
