@@ -18,19 +18,22 @@
 #ifndef INCLUDED_RENAME_PROTOS
 #define INCLUDED_RENAME_PROTOS
 
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+#include <cstdio>
 #include "compat/access.h"
 
-static inline int p_rename(const char * old, const char * new)
+namespace pvpgn
 {
+
+	static inline int p_rename(const char * oldpath, const char * newpath)
+	{
 #ifdef WIN32
-    if(access(new, F_OK) == 0)
-        if(remove(new) < 0)
-            return -1;
+		if (access(newpath, F_OK) == 0)
+		if (std::remove(newpath) < 0)
+			return -1;
 #endif
-    return rename(old, new);
+		return std::rename(oldpath, newpath);
+	}
+
 }
-		
+
 #endif
