@@ -22,16 +22,15 @@
 
 /* some sendto()s don't handle NULL, but send is called depreciated on BSD */
 #ifdef HAVE_SENDTO
-# ifdef HAVE_STDDEF_H
-#  include <stddef.h>
-# else
-#  ifndef NULL
-#   define NULL ((void *)0)
-#  endif
-# endif
+# include <cstddef>
 # define send(s, b, l, f) sendto(s, b, l, f, NULL, NULL)
 #else
-# error "This program requires sendto()"
+# ifdef HAVE_WINSOCK2_H
+#  include <winsock2.h>
+#  define send(s, b, l, f) sendto(s, b, l, f, NULL, NULL)
+# else
+#   error "This program requires sendto()"
+# endif
 #endif
 
 #endif
