@@ -20,8 +20,16 @@
 
 #ifndef HAVE_STRDUP
 
-extern char * strdup(char const * str);
+namespace pvpgn
+{
 
+	extern char * strdup(char const * str);
+
+}
+#else
+// dirty hack? but I don't like to include <string.h> directly when I just want this one...
+// better solutions welcome
+#  include <string.h>
 #endif
 
 #endif
