@@ -20,7 +20,12 @@
 
 #ifndef HAVE_STRSEP
 
-extern char * strsep(char * * str, char const * delim);
+namespace pvpgn
+{
+
+	extern char * strsep(char * * str, char const * delim);
+
+}
 
 #endif
 
