@@ -13,37 +13,35 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-#ifndef INCLUDED_UNAME_TYPES
-#define INCLUDED_UNAME_TYPES
+#ifndef INCLUDED_UNAME_H
+#define INCLUDED_UNAME_H
 
-#ifndef HAVE_UNAME
+#ifdef HAVE_UNAME
+#ifdef HAVE_SYS_UTSNAME_H
+#include <sys/utsname.h>
+#endif
+#else
 
 #ifndef SYS_NMLN
-# define SYS_NMLN 64
+#define SYS_NMLN 64
 #endif
 
-struct utsname
+namespace pvpgn
 {
-    char sysname[SYS_NMLN];
-    char nodename[SYS_NMLN];
-    char release[SYS_NMLN];
-    char version[SYS_NMLN];
-    char machine[SYS_NMLN];
-    char domainname[SYS_NMLN];
-};
+	struct utsname
+	{
+		char sysname[SYS_NMLN + 1];
+		char nodename[SYS_NMLN + 1];
+		char release[SYS_NMLN + 1];
+		char version[SYS_NMLN + 1];
+		char machine[SYS_NMLN + 1];
+		char domainname[SYS_NMLN + 1];
+	};
 
-#endif
+	int uname(struct utsname* buf);
+}
 
-#endif
-
-
-#ifndef INCLUDED_UNAME_PROTOS
-#define INCLUDED_UNAME_PROTOS
-
-#ifndef HAVE_UNAME
-extern int uname(struct utsname * buf);
-#endif
-
-#endif
+#endif // HAVE_UNAME
+#endif // INCLUDED_UNAME_H
\ No newline at end of file
