@@ -18,7 +18,13 @@
 #ifndef INCLUDED_BNETD_H
 #define INCLUDED_BNETD_H
 
-#include "s2s.h"
+#include "connection.h"
+
+namespace pvpgn
+{
+
+namespace d2cs
+{
 
 extern int bnetd_init(void);
 extern int bnetd_check(void);
@@ -27,4 +33,8 @@ extern int bnetd_destroy(t_connection * c);
 extern int bnetd_set_connection(t_connection * c);
 extern int bnetd_keepalive(void);
 
+}
+
+}
+
 #endif
