@@ -18,10 +18,20 @@
 #ifndef INCLUDED_HANDLE_BNETD_H
 #define INCLUDED_HANDLE_BNETD_H
 
-#include "connection.h"
 #include "common/packet.h"
+#include "connection.h"
+
+namespace pvpgn
+{
+
+namespace d2cs
+{
 
 extern int handle_bnetd_packet(t_connection * c, t_packet * packet);
 extern int handle_bnetd_init(t_connection * c);
 
+}
+
+}
+
 #endif
