@@ -18,11 +18,21 @@
 #ifndef INCLUDED_HANDLE_D2CS_H
 #define INCLUDED_HANDLE_D2CS_H
 
-#include "connection.h"
 #include "common/packet.h"
+#include "connection.h"
+
+namespace pvpgn
+{
+
+namespace d2cs
+{
 
 extern int d2cs_handle_d2cs_packet(t_connection * c, t_packet * packet);
 extern int d2cs_handle_client_creategame(t_connection * c, t_packet * packet);
 extern int d2cs_send_client_creategamewait(t_connection * c, unsigned int position);
 
+}
+
+}
+
 #endif
