@@ -18,16 +18,26 @@
 #ifndef INCLUDED_HANDLE_SIGNAL_H
 #define INCLUDED_HANDLE_SIGNAL_H
 
+namespace pvpgn
+{
+
+	namespace d2cs
+	{
+
 #ifndef WIN32
-extern int handle_signal_init(void);
+		extern int handle_signal_init(void);
 #else
-extern void signal_quit_wrapper(void);
-extern void signal_reload_config_wrapper(void);
-extern void signal_load_ladder_wrapper(void);
-extern void signal_exit_wrapper(void);
-extern void signal_restart_d2gs_wrapper(void);
+		extern void signal_quit_wrapper(void);
+		extern void signal_reload_config_wrapper(void);
+		extern void signal_load_ladder_wrapper(void);
+		extern void signal_exit_wrapper(void);
+		extern void signal_restart_d2gs_wrapper(void);
 #endif
 
-extern int handle_signal(void);
+		extern int handle_signal(void);
+
+	}
+
+}
 
 #endif
