@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005           Dizzy       
+ * Copyright (C) 2005           Dizzy
  * Copyright (C) 2005           Olaf Freyer (aaron@cs.tu-berlin.de)
  *
  * This program is free software; you can redistribute it and/or
@@ -20,14 +20,28 @@
 #ifndef __DDBS_CMDLINE_H_PROTOS__
 #define __D2DBS_CMDLINE_H_PROTOS__
 
-extern int cmdline_load(int argc, char * * argv);
-extern void cmdline_unload(void);
+namespace pvpgn
+{
 
-/* options exported by cmdline */
+	namespace d2dbs
+	{
+
+		extern int cmdline_load(int argc, char * * argv);
+		extern void cmdline_unload(void);
+
+		/* options exported by cmdline */
 #ifdef DO_DAEMONIZE
-extern int cmdline_get_foreground(void);
+		extern int cmdline_get_foreground(void);
 #endif
-extern const char* cmdline_get_preffile(void);
-extern const char* cmdline_get_logfile(void);
+		extern const char* cmdline_get_preffile(void);
+		extern const char* cmdline_get_logfile(void);
+#ifdef WIN32_GUI
+		extern unsigned cmdline_get_console(void);
+		extern unsigned cmdline_get_gui(void);
+#endif
+
+	}
+
+}
 
 #endif /* __D2DBS_CMDLINE_H_PROTOS__ */
