@@ -20,32 +20,42 @@
 
 #include "common/list.h"
 
-typedef struct {
-	int		sd;
-	unsigned int	ipaddr;
-	unsigned char	major;
-	unsigned char	minor;
-	unsigned char	type;
-	unsigned char	stats;
-	unsigned int	serverid;
-	unsigned int	verified;
-	unsigned char	serverip[16];
-	int		last_active;
-	int nCharsInReadBuffer;
-	int nCharsInWriteBuffer;
-	char ReadBuf[kBufferSize];
-	char WriteBuf[kBufferSize];
-} t_d2dbs_connection;
+namespace pvpgn
+{
 
-typedef struct raw_preset_d2gsid {
-	unsigned int	ipaddr;
-	unsigned int	d2gsid;
-	struct raw_preset_d2gsid	*next;
-} t_preset_d2gsid;
+	namespace d2dbs
+	{
 
-int dbs_server_main(void);
-int dbs_server_shutdown_connection(t_d2dbs_connection* conn);
+		typedef struct {
+			int		sd;
+			unsigned int	ipaddr;
+			unsigned char	major;
+			unsigned char	minor;
+			unsigned char	type;
+			unsigned char	stats;
+			unsigned int	serverid;
+			unsigned int	verified;
+			unsigned char	serverip[16];
+			int		last_active;
+			int nCharsInReadBuffer;
+			int nCharsInWriteBuffer;
+			char ReadBuf[kBufferSize];
+			char WriteBuf[kBufferSize];
+		} t_d2dbs_connection;
 
-extern t_list * dbs_server_connection_list;
+		typedef struct raw_preset_d2gsid {
+			unsigned int	ipaddr;
+			unsigned int	d2gsid;
+			struct raw_preset_d2gsid	*next;
+		} t_preset_d2gsid;
+
+		int dbs_server_main(void);
+		int dbs_server_shutdown_connection(t_d2dbs_connection* conn);
+
+		extern t_list * dbs_server_connection_list;
+
+	}
+
+}
 
 #endif
